==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/coupon/CouponLbxListItem.java <==
package global.hh.openapi.sdk.api.bean.coupon;


/**
 * @description: activity-controller
 * @author: 777771
 * @date: 2019-26-29 09:26:14
 */
public class CouponLbxListItem {

    /**
     * 第三方商家活动编码
     */
    private String actCode;

    /**
     * 第三方商家活动名称
     */
    private String actName;

    /**
     * 第三方商家会员卡号
     */
    private String cardId;

    /**
     * 用户购买时间
     */
    private Long createDate;

    /**
     * 用户手机号
     */
    private String mobile;

    /**
     * 第三方商家商品价格
     */
    private Long price;

    /**
     * 第三方商家商品名
     */
    private String prodName;

    /**
     * 防伪码
     */
    private String securityCode;

    /**
     * 第三方商家门店编码
     */
    private String terminalCode;

    /**
     * 用户名
     */
    private String userName;

    public CouponLbxListItem(){
    }

    public CouponLbxListItem(String actCode,String actName,String cardId,Long createDate,String mobile,Long price,String prodName,String securityCode,String terminalCode,String userName){
        this.actCode=actCode;
        this.actName=actName;
        this.cardId=cardId;
        this.createDate=createDate;
        this.mobile=mobile;
        this.price=price;
        this.prodName=prodName;
        this.securityCode=securityCode;
        this.terminalCode=terminalCode;
        this.userName=userName;
    }

    private String getActCode() {
        return actCode;
    }

    private void setActCode(String actCode) {
        this.actCode = actCode;
    }
    private String getActName() {
        return actName;
    }

    private void setActName(String actName) {
        this.actName = actName;
    }
    private String getCardId() {
        return cardId;
    }

    private void setCardId(String cardId) {
        this.cardId = cardId;
    }
    private Long getCreateDate() {
        return createDate;
    }

    private void setCreateDate(Long createDate) {
        this.createDate = createDate;
    }
    private String getMobile() {
        return mobile;
    }

    private void setMobile(String mobile) {
        this.mobile = mobile;
    }
    private Long getPrice() {
        return price;
    }

    private void setPrice(Long price) {
        this.price = price;
    }
    private String getProdName() {
        return prodName;
    }

    private void setProdName(String prodName) {
        this.prodName = prodName;
    }
    private String getSecurityCode() {
        return securityCode;
    }

    private void setSecurityCode(String securityCode) {
        this.securityCode = securityCode;
    }
    private String getTerminalCode() {
        return terminalCode;
    }

    private void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }
    private String getUserName() {
        return userName;
    }

    private void setUserName(String userName) {
        this.userName = userName;
    }
}

==> biostime-openapi-sdk-1.5.8.6-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/coupon/CouponLbxListItem.java <==
package global.hh.openapi.sdk.api.bean.coupon;


/**
 * @description: 第三方商家活动批量积分
 * @author: 12552
 * @date: 2019-14-28 16:14:28
 */
public class CouponLbxListItem {

    /**
     * 第三方商家活动编码
     */
    private String actCode;

    /**
     * 第三方商家活动名称
     */
    private String actName;

    /**
     * 第三方商家会员卡号
     */
    private String cardId;

    /**
     * 用户购买时间
     */
    private Long createDate;

    /**
     * 用户手机号
     */
    private String mobile;

    /**
     * 第三方商家商品价格
     */
    private Long price;

    /**
     * 第三方商家商品名
     */
    private String prodName;

    /**
     * 防伪码
     */
    private String securityCode;

    /**
     * 第三方商家门店编码
     */
    private String terminalCode;

    /**
     * 用户名
     */
    private String userName;

    public CouponLbxListItem(){
    }

    public CouponLbxListItem(String actCode,String actName,String cardId,Long createDate,String mobile,Long price,String prodName,String securityCode,String terminalCode,String userName){
        this.actCode=actCode;
        this.actName=actName;
        this.cardId=cardId;
        this.createDate=createDate;
        this.mobile=mobile;
        this.price=price;
        this.prodName=prodName;
        this.securityCode=securityCode;
        this.terminalCode=terminalCode;
        this.userName=userName;
    }

    public String getActCode() {
        return actCode;
    }

    public void setActCode(String actCode) {
        this.actCode = actCode;
    }
    public String getActName() {
        return actName;
    }

    public void setActName(String actName) {
        this.actName = actName;
    }
    public String getCardId() {
        return cardId;
    }

    public void setCardId(String cardId) {
        this.cardId = cardId;
    }
    public Long getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Long createDate) {
        this.createDate = createDate;
    }
    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
    public Long getPrice() {
        return price;
    }

    public void setPrice(Long price) {
        this.price = price;
    }
    public String getProdName() {
        return prodName;
    }

    public void setProdName(String prodName) {
        this.prodName = prodName;
    }
    public String getSecurityCode() {
        return securityCode;
    }

    public void setSecurityCode(String securityCode) {
        this.securityCode = securityCode;
    }
    public String getTerminalCode() {
        return terminalCode;
    }

    public void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
}
